pub trait Endpoint {
// Required methods
fn info(&self) -> &EndpointInfo;
async fn wait_enabled(&mut self);
}Expand description
Endpoint trait, common for OUT and IN. Endpoint is a buffer on a device that stores rx/tx data. Endpoint can be thought of as one end of a pipe/channel.
Required Methods
Sourcefn info(&self) -> &EndpointInfo
fn info(&self) -> &EndpointInfo
Get the endpoint address
Sourceasync fn wait_enabled(&mut self)
async fn wait_enabled(&mut self)
Wait for the endpoint to be enabled.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".